==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QBindingStorage_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qbindingstorage.h>
#include <QtCore/QVariant>
#include <QtCore/qpropertyprivate.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBindingStorage(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBindingStorage")
    QBindingStorage *_ptr = reinterpret_cast<QBindingStorage *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBindingStorage()
void __qt_construct_QBindingStorage_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBindingStorage()")
    Q_UNUSED(__java_arguments)
    QBindingStorage *__qt_this = new(__qtjambi_ptr) QBindingStorage();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QBindingStorage
void __qt_destruct_QBindingStorage(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBindingStorage")
    reinterpret_cast<QBindingStorage*>(ptr)->~QBindingStorage();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBindingStorage::QBindingStorage()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_initialize_1native__Lio_qt_core_QBindingStorage_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBindingStorage::QBindingStorage()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBindingStorage_0, sizeof(QBindingStorage), typeid(QBindingStorage), false, &deleter_QBindingStorage, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBindingStorage::bindingData(QUntypedPropertyData*,bool)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_bindingData_1native_1QUntypedPropertyData_1ptr_1bool__JJZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID data0,
 jboolean create1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::bindingData(QUntypedPropertyData*,bool)", __qt_this)
        QUntypedPropertyData* __qt_data0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(data0);
        QtPrivate::QPropertyBindingData* __qt_return_value = __qt_this->bindingData(__qt_data0, static_cast<bool>(create1));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBindingStorage::bindingData(const QUntypedPropertyData*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_bindingData_1native_1const_1QUntypedPropertyData_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID data0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::bindingData(const QUntypedPropertyData*)const", __qt_this)
        const QUntypedPropertyData* __qt_data0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(data0);
        QtPrivate::QPropertyBindingData* __qt_return_value = __qt_this->bindingData(__qt_data0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBindingStorage::isEmpty()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_isEmpty_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::isEmpty()", __qt_this)
        __java_return_value = __qt_this->isEmpty();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBindingStorage::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBindingStorage::registerDependency(const QUntypedPropertyData*)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_registerDependency_1native_1const_1QUntypedPropertyData_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::registerDependency(const QUntypedPropertyData*)const", __qt_this)
        const QUntypedPropertyData* __qt_data0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(data0);
        __qt_this->registerDependency(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBindingStorage(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QBindingStorage>("QBindingStorage", "io/qt/core/QBindingStorage");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBindingStorage, {
        ConstructorInfo(&__qt_construct_QBindingStorage_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBindingStorage);
    registerMetaType<QBindingStorage>("QBindingStorage");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QBindingStorage_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qbindingstorage.h>
#include <QtCore/QVariant>
#include <QtCore/qpropertyprivate.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBindingStorage(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBindingStorage")
    QBindingStorage *_ptr = reinterpret_cast<QBindingStorage *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBindingStorage()
void __qt_construct_QBindingStorage(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBindingStorage()")
    Q_UNUSED(__java_arguments)
    QBindingStorage *__qt_this = new(__qtjambi_ptr) QBindingStorage();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QBindingStorage::QBindingStorage()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_initialize_1native__Lio_qt_core_QBindingStorage_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBindingStorage::QBindingStorage()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBindingStorage, sizeof(QBindingStorage), typeid(QBindingStorage), false, &deleter_QBindingStorage, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QBindingStorage(QBindingStorage)
void __qt_construct_QBindingStorage_cref_QBindingStorage(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBindingStorage(QBindingStorage)")
    jobject other0 = __java_arguments[0].l;
    const QBindingStorage& __qt_other0 = qtjambi_cast<const QBindingStorage& >(__jni_env, other0);
    QBindingStorage *__qt_this = new(__qtjambi_ptr) QBindingStorage(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QBindingStorage::QBindingStorage(QBindingStorage)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_initialize_1native__Lio_qt_core_QBindingStorage_2Lio_qt_core_QBindingStorage_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBindingStorage::QBindingStorage(QBindingStorage)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBindingStorage_cref_QBindingStorage, sizeof(QBindingStorage), typeid(QBindingStorage), false, &deleter_QBindingStorage, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBindingStorage
void __qt_destruct_QBindingStorage(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBindingStorage")
    reinterpret_cast<QBindingStorage*>(ptr)->~QBindingStorage();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBindingStorage::bindingData(QUntypedPropertyData*,bool)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_bindingData_1native_1QUntypedPropertyData_1ptr_1bool__JJZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID data0,
 jboolean create1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::bindingData(QUntypedPropertyData*,bool)", __qt_this)
        QUntypedPropertyData* __qt_data0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(data0);
        QtPrivate::QPropertyBindingData* __qt_return_value = __qt_this->bindingData(__qt_data0, static_cast<bool>(create1));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBindingStorage::bindingData(const QUntypedPropertyData*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_bindingData_1native_1const_1QUntypedPropertyData_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID data0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::bindingData(const QUntypedPropertyData*)const", __qt_this)
        const QUntypedPropertyData* __qt_data0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(data0);
        QtPrivate::QPropertyBindingData* __qt_return_value = __qt_this->bindingData(__qt_data0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBindingStorage::isEmpty()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_isEmpty_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::isEmpty()", __qt_this)
        __java_return_value = __qt_this->isEmpty();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBindingStorage::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBindingStorage::registerDependency(const QUntypedPropertyData*)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_registerDependency_1native_1const_1QUntypedPropertyData_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBindingStorage::registerDependency(const QUntypedPropertyData*)const", __qt_this)
        const QUntypedPropertyData* __qt_data0 = QtJambiAPI::objectFromNativeId<QUntypedPropertyData>(data0);
        __qt_this->registerDependency(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBindingStorage_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QBindingStorage *__qt_this = QtJambiAPI::objectFromNativeId<QBindingStorage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBindingStorage(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QBindingStorage>("QBindingStorage", "io/qt/core/QBindingStorage");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBindingStorage, {
        ConstructorInfo(&__qt_construct_QBindingStorage, nullptr)
       ,ConstructorInfo(&__qt_construct_QBindingStorage_cref_QBindingStorage, "Lio/qt/core/QBindingStorage;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBindingStorage);
    registerMetaType<QBindingStorage>("QBindingStorage");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
